/*
 * Copyright (c) 2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * DescribeDatabases请求参数结构体
 */
export interface DescribeDatabasesRequest {
  /**
   * 返回数量，默认为10，最大值为100。
   */
  Limit?: number

  /**
   * 数据偏移量，从0开始，默认为0。
   */
  Offset?: number

  /**
   * 模糊匹配，库名关键字。
   */
  KeyWord?: string

  /**
   * 数据源唯名称，该名称可以通过DescribeDatasourceConnection接口查询到。默认为CosDataCatalog
   */
  DatasourceConnectionName?: string
}

/**
 * 工作组部分信息
 */
export interface WorkGroupMessage {
  /**
   * 工作组唯一Id
   */
  WorkGroupId: number

  /**
   * 工作组名称
   */
  WorkGroupName: string

  /**
      * 工作组描述
注意：此字段可能返回 null，表示取不到有效值。
      */
  WorkGroupDescription: string

  /**
   * 创建者
   */
  Creator: string

  /**
   * 工作组创建的时间，形如2021-07-28 16:19:32
   */
  CreateTime: string
}

/**
 * DeleteUser请求参数结构体
 */
export interface DeleteUserRequest {
  /**
   * 需要删除的用户的Id
   */
  UserIds: Array<string>
}

/**
 * CreateStoreLocation返回参数结构体
 */
export interface CreateStoreLocationResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * CreateScript返回参数结构体
 */
export interface CreateScriptResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * CreateTasksInOrder返回参数结构体
 */
export interface CreateTasksInOrderResponse {
  /**
   * 本批次提交的任务的批次Id
   */
  BatchId: string

  /**
   * 任务Id集合，按照执行顺序排列
   */
  TaskIdSet: Array<string>

  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DescribeTables返回参数结构体
 */
export interface DescribeTablesResponse {
  /**
   * 数据表对象列表。
   */
  TableList: Array<TableResponseInfo>

  /**
   * 实例总数。
   */
  TotalCount: number

  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * 工作组信息
 */
export interface WorkGroupInfo {
  /**
   * 查询到的工作组唯一Id
   */
  WorkGroupId: number

  /**
   * 工作组名称
   */
  WorkGroupName: string

  /**
      * 工作组描述
注意：此字段可能返回 null，表示取不到有效值。
      */
  WorkGroupDescription: string

  /**
   * 工作组关联的用户数量
   */
  UserNum: number

  /**
      * 工作组关联的用户集合
注意：此字段可能返回 null，表示取不到有效值。
      */
  UserSet: Array<UserMessage>

  /**
      * 工作组绑定的权限集合
注意：此字段可能返回 null，表示取不到有效值。
      */
  PolicySet: Array<Policy>

  /**
   * 工作组的创建人
   */
  Creator: string

  /**
   * 工作组的创建时间，形如2021-07-28 16:19:32
   */
  CreateTime: string
}

/**
 * ModifyUser返回参数结构体
 */
export interface ModifyUserResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DeleteScript返回参数结构体
 */
export interface DeleteScriptResponse {
  /**
   * 删除的脚本数量
   */
  ScriptsAffected: number

  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * 任务类型，任务如SQL查询等。
 */
export interface Task {
  /**
   * SQL查询任务
   */
  SQLTask?: SQLTask

  /**
   * Spark SQL查询任务
   */
  SparkSQLTask?: SQLTask
}

/**
 * DetachUserPolicy请求参数结构体
 */
export interface DetachUserPolicyRequest {
  /**
   * 用户Id，和CAM侧Uin匹配
   */
  UserId: string

  /**
   * 解绑的权限集合
   */
  PolicySet?: Array<Policy>
}

/**
 * DeleteWorkGroup返回参数结构体
 */
export interface DeleteWorkGroupResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DescribeTasks返回参数结构体
 */
export interface DescribeTasksResponse {
  /**
   * 任务对象列表。
   */
  TaskList: Array<TaskResponseInfo>

  /**
   * 实例总数。
   */
  TotalCount: number

  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * CreateTasksInOrder请求参数结构体
 */
export interface CreateTasksInOrderRequest {
  /**
   * 数据库名称。如果SQL语句中有数据库名称，优先使用SQL语句中的数据库，否则使用该参数指定的数据库。
   */
  DatabaseName: string

  /**
   * SQL任务信息
   */
  Tasks: TasksInfo

  /**
   * 数据源名称，默认为COSDataCatalog
   */
  DatasourceConnectionName?: string
}

/**
 * DetachWorkGroupPolicy返回参数结构体
 */
export interface DetachWorkGroupPolicyResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * CSV序列化及反序列化数据结构
 */
export interface CSVSerde {
  /**
   * CSV序列化转义符，默认为"\\"，最长8个字符，如 Escape: "/\"
   */
  Escape?: string

  /**
   * CSV序列化字段域符，默认为"'"，最长8个字符, 如 Quote: "\""
   */
  Quote?: string

  /**
   * CSV序列化分隔符，默认为"\t"，最长8个字符, 如 Separator: "\t"
   */
  Separator?: string
}

/**
 * CreateDatabase请求参数结构体
 */
export interface CreateDatabaseRequest {
  /**
   * 数据库基础信息
   */
  DatabaseInfo: DatabaseInfo

  /**
   * 数据源名称，默认为CosDataCatalog
   */
  DatasourceConnectionName?: string
}

/**
 * 绑定到同一个工作组的用户Id的集合
 */
export interface UserIdSetOfWorkGroupId {
  /**
   * 工作组Id
   */
  WorkGroupId: number

  /**
   * 用户Id集合，和CAM侧Uin匹配
   */
  UserIds: Array<string>
}

/**
 * 视图基本配置信息
 */
export interface ViewBaseInfo {
  /**
   * 该视图所属数据库名字
   */
  DatabaseName: string

  /**
   * 视图名称
   */
  ViewName: string
}

/**
 * CreateDatabase返回参数结构体
 */
export interface CreateDatabaseResponse {
  /**
   * 生成的建库执行语句对象。
   */
  Execution: Execution

  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DescribeTasks请求参数结构体
 */
export interface DescribeTasksRequest {
  /**
   * 返回数量，默认为10，最大值为100。
   */
  Limit?: number

  /**
   * 偏移量，默认为0。
   */
  Offset?: number

  /**
      * 过滤条件，如下支持的过滤类型，传参Name应为以下其中一个,每个过滤参数支持的过滤值不超过5个。
task-id - String - （任务ID过滤）task-id取值形如：e386471f-139a-4e59-877f-50ece8135b99。
task-state - String - （任务状态过滤）取值范围 0(初始化)， 1(运行中)， 2(成功)， -1(失败)。
task-sql-keyword - String - （SQL语句关键字）取值形如：DROP TABLE。
      */
  Filters?: Array<Filter>

  /**
   * 排序字段，支持如下字段类型，create-time
   */
  SortBy?: string

  /**
   * 排序方式，desc表示正序，asc表示反序， 默认为asc。
   */
  Sorting?: string

  /**
   * 起始时间点，格式为yyyy-mm-dd HH:MM:SS。默认为45天前的当前时刻
   */
  StartTime?: string

  /**
   * 结束时间点，格式为yyyy-mm-dd HH:MM:SS时间跨度在(0,30天]，支持最近45天数据查询。默认为当前时刻
   */
  EndTime?: string
}

/**
 * script实例。
 */
export interface Script {
  /**
      * 脚本Id，长度36字节。
注意：此字段可能返回 null，表示取不到有效值。
      */
  ScriptId: string

  /**
      * 脚本名称，长度0-25。
注意：此字段可能返回 null，表示取不到有效值。
      */
  ScriptName: string

  /**
      * 脚本描述，长度0-50。
注意：此字段可能返回 null，表示取不到有效值。
      */
  ScriptDesc: string

  /**
      * 默认关联数据库。
注意：此字段可能返回 null，表示取不到有效值。
      */
  DatabaseName: string

  /**
      * SQL描述，长度0-10000。
注意：此字段可能返回 null，表示取不到有效值。
      */
  SQLStatement: string

  /**
      * 更新时间戳， 单位：ms。
注意：此字段可能返回 null，表示取不到有效值。
      */
  UpdateTime: number
}

/**
 * DeleteWorkGroup请求参数结构体
 */
export interface DeleteWorkGroupRequest {
  /**
   * 要删除的工作组Id集合
   */
  WorkGroupIds: Array<number>
}

/**
 * 配置格式
 */
export interface KVPair {
  /**
      * 配置的key值
注意：此字段可能返回 null，表示取不到有效值。
      */
  Key: string

  /**
      * 配置的value值
注意：此字段可能返回 null，表示取不到有效值。
      */
  Value: string
}

/**
 * 数据表配置信息
 */
export interface TableBaseInfo {
  /**
   * 该数据表所属数据库名字
   */
  DatabaseName: string

  /**
   * 数据表名字
   */
  TableName: string

  /**
      * 该数据表所属数据源名字
注意：此字段可能返回 null，表示取不到有效值。
      */
  DatasourceConnectionName?: string
}

/**
 * 批量顺序执行任务集合
 */
export interface TasksInfo {
  /**
   * 任务类型，SQLTask：SQL查询任务。SparkSQLTask：Spark SQL查询任务
   */
  TaskType: string

  /**
   * 容错策略。Proceed：前面任务出错/取消后继续执行后面的任务。Terminate：前面的任务出错/取消之后终止后面任务的执行，后面的任务全部标记为已取消。
   */
  FailureTolerance: string

  /**
   * base64加密后的SQL语句，用";"号分隔每个SQL语句，一次最多提交50个任务。严格按照前后顺序执行
   */
  SQL: string

  /**
   * 任务的配置信息，当前仅支持SparkSQLTask任务。
   */
  Config?: Array<KVPair>
}

/**
 * AttachWorkGroupPolicy请求参数结构体
 */
export interface AttachWorkGroupPolicyRequest {
  /**
   * 工作组Id
   */
  WorkGroupId: number

  /**
   * 要绑定的策略集合
   */
  PolicySet?: Array<Policy>
}

/**
 * CreateUser返回参数结构体
 */
export interface CreateUserResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DeleteUser返回参数结构体
 */
export interface DeleteUserResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * CreateStoreLocation请求参数结构体
 */
export interface CreateStoreLocationRequest {
  /**
   * 计算结果存储cos路径，如：cosn://bucketname/
   */
  StoreLocation: string
}

/**
 * 数据表分块信息。
 */
export interface Partition {
  /**
   * 分区列名。
   */
  Name: string

  /**
   * 分区类型。
   */
  Type: string

  /**
   * 对分区的描述。
   */
  Comment: string
}

/**
 * CreateTask请求参数结构体
 */
export interface CreateTaskRequest {
  /**
   * 计算任务，该参数中包含任务类型及其相关配置信息
   */
  Task: Task

  /**
   * 数据库名称。任务在执行前均会USE该数据库， 除了首次建库时，其他情况建议均添加上。
   */
  DatabaseName?: string

  /**
   * 默认数据源名称。
   */
  DatasourceConnectionName?: string
}

/**
 * 数据库和数据表属性信息
 */
export interface Property {
  /**
   * 属性key名称。
   */
  Key: string

  /**
   * 属性key对应的value。
   */
  Value: string
}

/**
 * CreateTable请求参数结构体
 */
export interface CreateTableRequest {
  /**
   * 数据表配置信息
   */
  TableInfo: TableInfo
}

/**
 * DescribeWorkGroups返回参数结构体
 */
export interface DescribeWorkGroupsResponse {
  /**
   * 工作组总数
   */
  TotalCount: number

  /**
   * 工作组信息集合
   */
  WorkGroupSet: Array<WorkGroupInfo>

  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DescribeUsers请求参数结构体
 */
export interface DescribeUsersRequest {
  /**
   * 指定查询的子用户uin，用户需要通过CreateUser接口创建。
   */
  UserId?: string

  /**
   * 偏移量，默认为0
   */
  Offset?: number

  /**
   * 返回数量，默认20，最大值100
   */
  Limit?: number

  /**
   * 排序字段，支持如下字段类型，create-time
   */
  SortBy?: string

  /**
   * 排序方式，desc表示正序，asc表示反序， 默认为asc
   */
  Sorting?: string
}

/**
 * DescribeScripts请求参数结构体
 */
export interface DescribeScriptsRequest {
  /**
   * 返回数量，默认为10，最大值为100。
   */
  Limit?: number

  /**
   * 偏移量，默认为0。
   */
  Offset?: number

  /**
   * 按字段排序，支持如下字段类型，update-time
   */
  SortBy?: string

  /**
   * 排序方式，desc表示正序，asc表示反序
   */
  Sorting?: string

  /**
      * 过滤条件，如下支持的过滤类型，传参Name应为其一
script-id - String - （过滤条件）script-id取值形如：157de0d1-26b4-4df2-a2d0-b64afc406c25。
script-name-keyword - String - （过滤条件）数据表名称,形如：script-test。
      */
  Filters?: Array<Filter>
}

/**
 * DeleteUsersFromWorkGroup返回参数结构体
 */
export interface DeleteUsersFromWorkGroupResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * AddUsersToWorkGroup请求参数结构体
 */
export interface AddUsersToWorkGroupRequest {
  /**
   * 要操作的工作组和用户信息
   */
  AddInfo: UserIdSetOfWorkGroupId
}

/**
 * DescribeStoreLocation请求参数结构体
 */
export type DescribeStoreLocationRequest = null

/**
 * DescribeViews请求参数结构体
 */
export interface DescribeViewsRequest {
  /**
   * 列出该数据库下所属数据表。
   */
  DatabaseName: string

  /**
   * 返回数量，默认为10，最大值为100。
   */
  Limit?: number

  /**
   * 数据偏移量，从0开始，默认为0。
   */
  Offset?: number

  /**
      * 过滤条件，如下支持的过滤类型，传参Name应为其一
view-name - String - （过滤条件）数据表名称,形如：view-001。
view-id - String - （过滤条件）view id形如：12342。
      */
  Filters?: Array<Filter>

  /**
   * 数据库所属的数据源名称
   */
  DatasourceConnectionName?: string
}

/**
 * 授权用户信息
 */
export interface UserInfo {
  /**
   * 用户Id，和子用户uin相同
   */
  UserId: string

  /**
      * 用户描述信息，方便区分不同用户
注意：此字段可能返回 null，表示取不到有效值。
      */
  UserDescription: string

  /**
      * 单独给用户绑定的权限集合
注意：此字段可能返回 null，表示取不到有效值。
      */
  PolicySet: Array<Policy>

  /**
   * 当前用户的创建者
   */
  Creator: string

  /**
   * 创建时间，格式如2021-07-28 16:19:32
   */
  CreateTime: string

  /**
      * 关联的工作组集合
注意：此字段可能返回 null，表示取不到有效值。
      */
  WorkGroupSet: Array<WorkGroupMessage>

  /**
      * 是否是管理员账号
注意：此字段可能返回 null，表示取不到有效值。
      */
  IsOwner: boolean
}

/**
 * AttachWorkGroupPolicy返回参数结构体
 */
export interface AttachWorkGroupPolicyResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * ModifyWorkGroup返回参数结构体
 */
export interface ModifyWorkGroupResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * AttachUserPolicy请求参数结构体
 */
export interface AttachUserPolicyRequest {
  /**
   * 用户Id，和子用户uin相同，需要先使用CreateUser接口创建用户。可以使用DescribeUsers接口查看。
   */
  UserId: string

  /**
   * 鉴权策略集合
   */
  PolicySet?: Array<Policy>
}

/**
 * CancelTask请求参数结构体
 */
export interface CancelTaskRequest {
  /**
   * 任务Id，全局唯一
   */
  TaskId: string
}

/**
 * 任务实例。
 */
export interface TaskResponseInfo {
  /**
   * 任务所属Database的名称。
   */
  DatabaseName: string

  /**
   * 任务数据量。
   */
  DataAmount: number

  /**
   * 任务Id。
   */
  Id: string

  /**
   * 计算时长，单位： ms。
   */
  UsedTime: number

  /**
   * 任务输出路径。
   */
  OutputPath: string

  /**
   * 任务创建时间。
   */
  CreateTime: string

  /**
   * 任务状态：0 初始化， 1 执行中， 2 执行成功，-1 执行失败，-3 已取消。
   */
  State: number

  /**
   * 任务SQL类型，DDL|DML等
   */
  SQLType: string

  /**
   * 任务SQL语句
   */
  SQL: string

  /**
   * 结果是否过期。
   */
  ResultExpired: boolean

  /**
   * 数据影响统计信息。
   */
  RowAffectInfo: string

  /**
      * 任务结果数据表。
注意：此字段可能返回 null，表示取不到有效值。
      */
  DataSet: string

  /**
   * 失败信息, 例如：errorMessage。该字段已废弃。
   */
  Error: string

  /**
   * 任务执行进度num/100(%)
   */
  Percentage: number

  /**
   * 任务执行输出信息。
   */
  OutputMessage: string

  /**
   * 执行SQL的引擎类型
   */
  TaskType: string
}

/**
 * 文本格式
 */
export interface TextFile {
  /**
   * 文本类型，本参数取值为TextFile。
   */
  Format: string

  /**
      * 处理文本用的正则表达式。
注意：此字段可能返回 null，表示取不到有效值。
      */
  Regex: string
}

/**
 * BindWorkGroupsToUser返回参数结构体
 */
export interface BindWorkGroupsToUserResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DescribeStoreLocation返回参数结构体
 */
export interface DescribeStoreLocationResponse {
  /**
      * 返回用户设置的结果存储位置路径，如果未设置则返回空字符串：""
注意：此字段可能返回 null，表示取不到有效值。
      */
  StoreLocation: string

  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DeleteScript请求参数结构体
 */
export interface DeleteScriptRequest {
  /**
   * 脚本id，其可以通过DescribeScripts接口提取
   */
  ScriptIds: Array<string>
}

/**
 * SQL语句对象
 */
export interface Execution {
  /**
   * 自动生成SQL语句。
   */
  SQL: string
}

/**
 * CreateTable返回参数结构体
 */
export interface CreateTableResponse {
  /**
   * 生成的建表执行语句对象。
   */
  Execution: Execution

  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * CreateScript请求参数结构体
 */
export interface CreateScriptRequest {
  /**
   * 脚本名称，最大不能超过255个字符。
   */
  ScriptName: string

  /**
   * base64编码后的sql语句
   */
  SQLStatement: string

  /**
   * 脚本描述， 不能超过50个字符
   */
  ScriptDesc?: string

  /**
   * 数据库名称
   */
  DatabaseName?: string
}

/**
 * BindWorkGroupsToUser请求参数结构体
 */
export interface BindWorkGroupsToUserRequest {
  /**
   * 绑定的用户和工作组信息
   */
  AddInfo: WorkGroupIdSetOfUserId
}

/**
 * 数据表列信息。
 */
export interface Column {
  /**
   * 列名称，不区分大小写，最大支持25个字符。
   */
  Name: string

  /**
      * 列类型，支持如下类型定义:
string|tinyint|smallint|int|bigint|boolean|float|double|decimal|timestamp|date|binary|array<data_type>|map<primitive_type, data_type>|struct<col_name : data_type [COMMENT col_comment], ...>|uniontype<data_type, data_type, ...>。
      */
  Type: string

  /**
      * 对该类的注释。
注意：此字段可能返回 null，表示取不到有效值。
      */
  Comment?: string
}

/**
 * 查询列表过滤条件参数
 */
export interface Filter {
  /**
   * 属性名称, 若存在多个Filter时，Filter间的关系为逻辑或（OR）关系。
   */
  Name: string

  /**
   * 属性值, 若同一个Filter存在多个Values，同一Filter下Values间的关系为逻辑或（OR）关系。
   */
  Values: Array<string>
}

/**
 * DescribeUsers返回参数结构体
 */
export interface DescribeUsersResponse {
  /**
   * 查询到的用户总数
   */
  TotalCount: number

  /**
   * 查询到的授权用户信息集合
   */
  UserSet: Array<UserInfo>

  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * 数据表数据格式。
 */
export interface DataFormat {
  /**
      * 文本格式，TextFile。
注意：此字段可能返回 null，表示取不到有效值。
      */
  TextFile: TextFile

  /**
      * 文本格式，CSV。
注意：此字段可能返回 null，表示取不到有效值。
      */
  CSV: CSV

  /**
      * 文本格式，Json。
注意：此字段可能返回 null，表示取不到有效值。
      */
  Json: Other

  /**
      * Parquet格式
注意：此字段可能返回 null，表示取不到有效值。
      */
  Parquet: Other

  /**
      * ORC格式
注意：此字段可能返回 null，表示取不到有效值。
      */
  ORC: Other

  /**
      * AVRO格式
注意：此字段可能返回 null，表示取不到有效值。
      */
  AVRO: Other
}

/**
 * 查询视图信息对象
 */
export interface ViewResponseInfo {
  /**
   * 视图基本信息。
   */
  ViewBaseInfo: ViewBaseInfo

  /**
      * 视图列信息。
注意：此字段可能返回 null，表示取不到有效值。
      */
  Columns: Array<Column>

  /**
      * 视图属性信息。
注意：此字段可能返回 null，表示取不到有效值。
      */
  Properties: Array<Property>

  /**
   * 视图创建时间。
   */
  CreateTime: string

  /**
   * 视图更新时间。
   */
  ModifiedTime: string
}

/**
 * CreateUser请求参数结构体
 */
export interface CreateUserRequest {
  /**
   * 需要授权的子用户uin，可以通过腾讯云控制台右上角 → “账号信息” → “账号ID进行查看”。
   */
  UserId: string

  /**
   * 用户描述信息，方便区分不同用户
   */
  UserDescription?: string

  /**
   * 绑定到用户的权限集合
   */
  PolicySet?: Array<Policy>
}

/**
 * ModifyWorkGroup请求参数结构体
 */
export interface ModifyWorkGroupRequest {
  /**
   * 工作组Id
   */
  WorkGroupId: number

  /**
   * 工作组描述
   */
  WorkGroupDescription: string
}

/**
 * CancelTask返回参数结构体
 */
export interface CancelTaskResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * 返回数据表的相关信息。
 */
export interface TableInfo {
  /**
   * 数据表配置信息。
   */
  TableBaseInfo: TableBaseInfo

  /**
   * 数据表格式。每次入参可选如下其一的KV结构，[TextFile，CSV，Json, Parquet, ORC, AVRD]。
   */
  DataFormat: DataFormat

  /**
   * 数据表列信息。
   */
  Columns: Array<Column>

  /**
   * 数据表分块信息。
   */
  Partitions: Array<Partition>

  /**
   * 数据存储路径。当前仅支持cos路径，格式如下：cosn://bucket-name/filepath。
   */
  Location: string
}

/**
 * 同一个用户绑定的工作组集合
 */
export interface WorkGroupIdSetOfUserId {
  /**
   * 用户Id，和CAM侧Uin匹配
   */
  UserId: string

  /**
   * 工作组Id集合
   */
  WorkGroupIds: Array<number>
}

/**
 * CreateWorkGroup返回参数结构体
 */
export interface CreateWorkGroupResponse {
  /**
   * 工作组Id，全局唯一
   */
  WorkGroupId: number

  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DescribeTables请求参数结构体
 */
export interface DescribeTablesRequest {
  /**
   * 列出该数据库下所属数据表。
   */
  DatabaseName: string

  /**
   * 返回数量，默认为10，最大值为100。
   */
  Limit?: number

  /**
   * 数据偏移量，从0开始，默认为0。
   */
  Offset?: number

  /**
      * 过滤条件，如下支持的过滤类型，传参Name应为其一
table-name - String - （过滤条件）数据表名称,形如：table-001。
table-id - String - （过滤条件）table id形如：12342。
      */
  Filters?: Array<Filter>

  /**
   * 指定查询的数据源名称，默认为CosDataCatalog
   */
  DatasourceConnectionName?: string
}

/**
 * DescribeDatabases返回参数结构体
 */
export interface DescribeDatabasesResponse {
  /**
   * 数据库对象列表。
   */
  DatabaseList: Array<DatabaseResponseInfo>

  /**
   * 实例总数。
   */
  TotalCount: number

  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * 数据库对象
 */
export interface DatabaseInfo {
  /**
   * 数据库名称。
   */
  DatabaseName: string

  /**
      * 数据库描述信息，长度 0~256。
注意：此字段可能返回 null，表示取不到有效值。
      */
  Comment?: string

  /**
      * 数据库属性列表。
注意：此字段可能返回 null，表示取不到有效值。
      */
  Properties?: Array<Property>
}

/**
 * UnbindWorkGroupsFromUser请求参数结构体
 */
export interface UnbindWorkGroupsFromUserRequest {
  /**
   * 解绑的工作组Id和用户Id的关联关系
   */
  AddInfo: WorkGroupIdSetOfUserId
}

/**
 * DescribeTable请求参数结构体
 */
export interface DescribeTableRequest {
  /**
   * 查询对象表名称
   */
  TableName: string

  /**
   * 查询表所在的数据库名称。
   */
  DatabaseName: string

  /**
   * 查询表所在的数据源名称
   */
  DatasourceConnectionName?: string
}

/**
 * 数据格式其它类型。
 */
export interface Other {
  /**
   * 枚举类型，默认值为Json，可选值为[Json, Parquet, ORC, AVRD]之一。
   */
  Format: string
}

/**
 * CSV类型数据格式
 */
export interface CSV {
  /**
   * 压缩格式，["Snappy", "Gzip", "None"选一]。
   */
  CodeCompress?: string

  /**
   * CSV序列化及反序列化数据结构。
   */
  CSVSerde?: CSVSerde

  /**
      * 标题行，默认为0。
注意：此字段可能返回 null，表示取不到有效值。
      */
  HeadLines?: number

  /**
      * 格式，默认值为CSV
注意：此字段可能返回 null，表示取不到有效值。
      */
  Format?: string
}

/**
 * DeleteUsersFromWorkGroup请求参数结构体
 */
export interface DeleteUsersFromWorkGroupRequest {
  /**
   * 要删除的用户信息
   */
  AddInfo: UserIdSetOfWorkGroupId
}

/**
 * 权限对象
 */
export interface Policy {
  /**
   * 需要授权的数据源名称，当前仅支持COSDataCatalog或者*
   */
  Catalog: string

  /**
   * 需要授权的数据库名，填*代表当前Catalog下所有数据库
   */
  Database: string

  /**
   * 需要授权的表名，填*代表当前Database下所有表
   */
  Table: string

  /**
   * 授权粒度，当前只支持ALL，即全部权限
   */
  Operation: string
}

/**
 * CreateTasks请求参数结构体
 */
export interface CreateTasksRequest {
  /**
   * 数据库名称。如果SQL语句中有数据库名称，优先使用SQL语句中的数据库，否则使用该参数指定的数据库。
   */
  DatabaseName: string

  /**
   * SQL任务信息
   */
  Tasks: TasksInfo

  /**
   * 数据源名称，默认为COSDataCatalog
   */
  DatasourceConnectionName?: string
}

/**
 * CreateTask返回参数结构体
 */
export interface CreateTaskResponse {
  /**
      * 任务ID
注意：此字段可能返回 null，表示取不到有效值。
      */
  TaskId: string

  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DescribeWorkGroups请求参数结构体
 */
export interface DescribeWorkGroupsRequest {
  /**
   * 查询的工作组Id，不填或填0表示不过滤。
   */
  WorkGroupId?: number

  /**
   * 过滤条件，当前仅支持按照工作组名称进行模糊搜索。Key为workgroup-name
   */
  Filters?: Array<Filter>

  /**
   * 偏移量，默认为0
   */
  Offset?: number

  /**
   * 返回数量，默认20，最大值100
   */
  Limit?: number

  /**
   * 排序字段，支持如下字段类型，create-time
   */
  SortBy?: string

  /**
   * 排序方式，desc表示正序，asc表示反序， 默认为asc
   */
  Sorting?: string
}

/**
 * DescribeTable返回参数结构体
 */
export interface DescribeTableResponse {
  /**
   * 数据表对象
   */
  Table: TableResponseInfo

  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * 查询表信息对象
 */
export interface TableResponseInfo {
  /**
   * 数据表基本信息。
   */
  TableBaseInfo: TableBaseInfo

  /**
      * 数据表列信息。
注意：此字段可能返回 null，表示取不到有效值。
      */
  Columns: Array<Column>

  /**
      * 数据表分块信息。
注意：此字段可能返回 null，表示取不到有效值。
      */
  Partitions: Array<Partition>

  /**
      * 数据存储路径。
注意：此字段可能返回 null，表示取不到有效值。
      */
  Location: string

  /**
      * 数据表属性信息。
注意：此字段可能返回 null，表示取不到有效值。
      */
  Properties: Array<Property>

  /**
      * 数据表更新时间, 单位: ms。
注意：此字段可能返回 null，表示取不到有效值。
      */
  ModifiedTime: string

  /**
      * 数据表创建时间,单位: ms。
注意：此字段可能返回 null，表示取不到有效值。
      */
  CreateTime: string

  /**
      * 数据格式。
注意：此字段可能返回 null，表示取不到有效值。
      */
  InputFormat: string
}

/**
 * AddUsersToWorkGroup返回参数结构体
 */
export interface AddUsersToWorkGroupResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DetachUserPolicy返回参数结构体
 */
export interface DetachUserPolicyResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * CreateTasks返回参数结构体
 */
export interface CreateTasksResponse {
  /**
   * 本批次提交的任务的批次Id
   */
  BatchId: string

  /**
   * 任务Id集合，按照执行顺序排列
   */
  TaskIdSet: Array<string>

  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * UnbindWorkGroupsFromUser返回参数结构体
 */
export interface UnbindWorkGroupsFromUserResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * CreateWorkGroup请求参数结构体
 */
export interface CreateWorkGroupRequest {
  /**
   * 工作组名称
   */
  WorkGroupName: string

  /**
   * 工作组描述
   */
  WorkGroupDescription?: string

  /**
   * 工作组绑定的鉴权策略集合
   */
  PolicySet?: Array<Policy>
}

/**
 *  SQL查询任务
 */
export interface SQLTask {
  /**
   * base64加密后的SQL语句
   */
  SQL: string

  /**
   * 任务的配置信息
   */
  Config?: Array<KVPair>
}

/**
 * 用户部分信息
 */
export interface UserMessage {
  /**
   * 用户Id，和CAM侧子用户Uin匹配
   */
  UserId: string

  /**
      * 用户描述
注意：此字段可能返回 null，表示取不到有效值。
      */
  UserDescription: string

  /**
   * 当前用户的创建者
   */
  Creator: string

  /**
   * 当前用户的创建时间，形如2021-07-28 16:19:32
   */
  CreateTime: string
}

/**
 * AttachUserPolicy返回参数结构体
 */
export interface AttachUserPolicyResponse {
  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DescribeScripts返回参数结构体
 */
export interface DescribeScriptsResponse {
  /**
      * Script列表
注意：此字段可能返回 null，表示取不到有效值。
      */
  Scripts: Array<Script>

  /**
   * 实例总数
   */
  TotalCount: number

  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DetachWorkGroupPolicy请求参数结构体
 */
export interface DetachWorkGroupPolicyRequest {
  /**
   * 工作组Id
   */
  WorkGroupId: number

  /**
   * 解绑的权限集合
   */
  PolicySet?: Array<Policy>
}

/**
 * DescribeViews返回参数结构体
 */
export interface DescribeViewsResponse {
  /**
   * 视图对象列表。
   */
  ViewList: Array<ViewResponseInfo>

  /**
   * 实例总数。
   */
  TotalCount: number

  /**
   * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * ModifyUser请求参数结构体
 */
export interface ModifyUserRequest {
  /**
   * 用户Id，和CAM侧Uin匹配
   */
  UserId: string

  /**
   * 用户描述
   */
  UserDescription: string
}

/**
 * 数据库对象
 */
export interface DatabaseResponseInfo {
  /**
   * 数据库名称。
   */
  DatabaseName: string

  /**
      * 数据库描述信息，长度 0~256。
注意：此字段可能返回 null，表示取不到有效值。
      */
  Comment?: string

  /**
      * 数据库属性列表。
注意：此字段可能返回 null，表示取不到有效值。
      */
  Properties?: Array<Property>

  /**
      * 数据库创建时间戳，单位：s。
注意：此字段可能返回 null，表示取不到有效值。
      */
  CreateTime?: string

  /**
      * 数据库更新时间戳，单位：s。
注意：此字段可能返回 null，表示取不到有效值。
      */
  ModifiedTime?: string
}
